@@ -14,7 +14,7 @@
 #include "lspclientservermanager.h"
 #include "lspclientsymbolview.h"
 #include "lspclientutils.h"
-#include "lsptooltip.h"
+#include "texthint/KateTextHintManager.h"
 
 #include "lspclient_debug.h"
 
@@ -26,19 +26,20 @@
 #include <KStandardAction>
 #include <KXMLGUIFactory>
 
-#include <KTextEditor/CodeCompletionInterface>
 #include <KTextEditor/Document>
 #include <KTextEditor/MainWindow>
 #include <KTextEditor/Message>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#include <KTextEditor/CodeCompletionInterface>
 #include <KTextEditor/MovingInterface>
+#include <ktexteditor/configinterface.h>
+#include <ktexteditor/markinterface.h>
+#endif
 #include <KTextEditor/SessionConfigInterface>
 #include <KTextEditor/View>
 #include <KXMLGUIClient>
 
-#include <ktexteditor/configinterface.h>
 #include <ktexteditor/editor.h>
-#include <ktexteditor/markinterface.h>
-#include <ktexteditor/movinginterface.h>
 #include <ktexteditor/movingrange.h>
 #include <ktexteditor_version.h>
 
@@ -112,7 +113,11 @@ private:
     _kind m_value;
 };
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+static constexpr KTextEditor::Document::MarkTypes markType = KTextEditor::Document::markType31;
+#else
 static constexpr KTextEditor::MarkInterface::MarkTypes markType = KTextEditor::MarkInterface::markType31;
+#endif
 }
 
 KTextEditor::Document *findDocument(KTextEditor::MainWindow *mainWindow, const QUrl &url)
@@ -233,7 +238,7 @@ class CtrlHoverFeedback : public QObject
 public:
     void highlight(KTextEditor::View *activeView)
     {
-        // sanity checks
+        // sanity checksQString
         if (!activeView) {
             return;
         }
@@ -254,6 +259,21 @@ public:
         if (mr) {
             mr->setRange(range);
         } else {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+            mr.reset(doc->newMovingRange(range));
+            connect(doc, &KTextEditor::Document::aboutToInvalidateMovingInterfaceContent, this, &CtrlHoverFeedback::clearMovingRange, Qt::UniqueConnection);
+            connect(doc, &KTextEditor::Document::aboutToDeleteMovingInterfaceContent, this, &CtrlHoverFeedback::clearMovingRange, Qt::UniqueConnection);
+            connect(doc,
+                    SIGNAL(aboutToInvalidateMovingInterfaceContent(KTextEditor::Document *)),
+                    this,
+                    SLOT(clear(KTextEditor::Document *)),
+                    Qt::UniqueConnection);
+            connect(doc,
+                    SIGNAL(aboutToDeleteMovingInterfaceContent(KTextEditor::Document *)),
+                    this,
+                    SLOT(clear(KTextEditor::Document *)),
+                    Qt::UniqueConnection);
+#else
             auto miface = qobject_cast<KTextEditor::MovingInterface *>(doc);
             if (!miface) {
                 return;
@@ -263,14 +283,15 @@ public:
             connect(doc,
                     SIGNAL(aboutToInvalidateMovingInterfaceContent(KTextEditor::Document*)),
                     this,
-                    SLOT(clear(KTextEditor::Document*)),
+                    SLOT(clearMovingRange(KTextEditor::Document*)),
                     Qt::UniqueConnection);
             connect(doc,
                     SIGNAL(aboutToDeleteMovingInterfaceContent(KTextEditor::Document*)),
                     this,
-                    SLOT(clear(KTextEditor::Document*)),
+                    SLOT(clearMovingRange(KTextEditor::Document*)),
                     Qt::UniqueConnection);
             // clang-format on
+#endif
         }
 
         static KTextEditor::Attribute::Ptr attr;
@@ -311,7 +332,7 @@ public:
     }
 
 private:
-    Q_SLOT void clear(KTextEditor::Document *doc)
+    Q_SLOT void clearMovingRange(KTextEditor::Document *doc)
     {
         if (doc) {
             auto it = docs.find(doc);
@@ -337,8 +358,8 @@ class LSPClientPluginViewImpl : public QObject, public KXMLGUIClient
     KTextEditor::MainWindow *m_mainWindow;
     std::shared_ptr<LSPClientServerManager> m_serverManager;
     std::unique_ptr<LSPClientCompletion> m_completion;
+    KateTextHintProvider m_textHintprovider;
     std::unique_ptr<LSPClientHover> m_hover;
-    std::unique_ptr<KTextEditor::TextHintProvider> m_forwardHover;
     std::unique_ptr<LSPClientSymbolView> m_symbolView;
 
     QPointer<QAction> m_findDef;
@@ -399,9 +420,6 @@ class LSPClientPluginViewImpl : public QObject, public KXMLGUIClient
     // views on which completions have been registered
     QSet<KTextEditor::View *> m_completionViews;
 
-    // views on which hovers have been registered
-    QSet<KTextEditor::View *> m_hoverViews;
-
     // outstanding request
     LSPClientServer::RequestHandle m_handle;
     // timeout on request
@@ -418,34 +436,17 @@ class LSPClientPluginViewImpl : public QObject, public KXMLGUIClient
 
     CtrlHoverFeedback m_ctrlHoverFeedback = {};
 
-    // inner class that forwards directly to method for convenience
-    class ForwardingTextHintProvider : public KTextEditor::TextHintProvider
-    {
-        typedef LSPClientPluginViewImpl parent_type;
-        parent_type *m_parent;
-
-    public:
-        ForwardingTextHintProvider(parent_type *parent)
-            : m_parent(parent)
-        {
-            Q_ASSERT(m_parent);
-        }
-
-        virtual QString textHint(KTextEditor::View *view, const KTextEditor::Cursor &position) override
-        {
-            return m_parent->onTextHint(view, position);
-        }
-    };
-
     SemanticHighlighter m_semHighlightingManager;
     InlayHintsManager m_inlayHintsHandler;
 
     class LSPDiagnosticProvider : public DiagnosticsProvider
     {
     public:
-        LSPDiagnosticProvider(LSPClientPluginViewImpl *lsp)
-            : m_lsp(lsp)
+        LSPDiagnosticProvider(KTextEditor::MainWindow *mainWin, LSPClientPluginViewImpl *lsp)
+            : DiagnosticsProvider(mainWin, lsp)
+            , m_lsp(lsp)
         {
+            name = i18n("LSP");
         }
 
         QJsonObject suppressions(KTextEditor::Document *doc) const override
@@ -464,15 +465,6 @@ class LSPClientPluginViewImpl : public QObject, public KXMLGUIClient
 
     LSPDiagnosticProvider m_diagnosticProvider;
 
-Q_SIGNALS:
-
-    /**
-     * Signal for location changed.
-     * @param document url
-     * @param c pos in document
-     */
-    void addPositionToHistory(const QUrl &url, KTextEditor::Cursor c);
-
 public:
     LSPClientPluginViewImpl(LSPClientPlugin *plugin, KTextEditor::MainWindow *mainWin, std::shared_ptr<LSPClientServerManager> serverManager)
         : QObject(mainWin)
@@ -480,12 +472,12 @@ public:
         , m_mainWindow(mainWin)
         , m_serverManager(std::move(serverManager))
         , m_completion(LSPClientCompletion::new_(m_serverManager))
-        , m_hover(LSPClientHover::new_(m_serverManager))
-        , m_forwardHover(new ForwardingTextHintProvider(this))
+        , m_textHintprovider(m_mainWindow, this)
+        , m_hover(LSPClientHover::new_(m_serverManager, &m_textHintprovider))
         , m_symbolView(LSPClientSymbolView::new_(plugin, mainWin, m_serverManager))
         , m_semHighlightingManager(m_serverManager)
         , m_inlayHintsHandler(m_serverManager, this)
-        , m_diagnosticProvider(this)
+        , m_diagnosticProvider(mainWin, this)
     {
         KXMLGUIClient::setComponentName(QStringLiteral("lspclient"), i18n("LSP Client"));
         setXMLFile(QStringLiteral("ui.rc"));
@@ -684,8 +676,8 @@ public:
         connect(m_plugin, &LSPClientPlugin::update, this, &self_type::configUpdated);
 
         m_diagnosticProvider.setObjectName(QStringLiteral("LSPDiagnosticProvider"));
-        Utils::registerDiagnosticsProvider(&m_diagnosticProvider, m_mainWindow);
         connect(&m_diagnosticProvider, &DiagnosticsProvider::requestFixes, this, &self_type::fixDiagnostic);
+        connect(&m_textHintprovider, &KateTextHintProvider::textHintRequested, this, &self_type::onTextHint);
 
         connect(m_mainWindow, &KTextEditor::MainWindow::viewCreated, this, &self_type::onViewCreated);
 
@@ -783,7 +775,11 @@ public:
             return QObject::eventFilter(obj, event);
         }
 
-        auto mouseEvent = dynamic_cast<QMouseEvent *>(event);
+        if (event->type() != QEvent::MouseButtonPress && event->type() != QEvent::MouseMove) {
+            return QObject::eventFilter(obj, event);
+        }
+
+        auto mouseEvent = static_cast<QMouseEvent *>(event);
         // we are only concerned with mouse events for now :)
         if (!mouseEvent) {
             return false;
@@ -847,12 +843,11 @@ public:
 
         // unregister all code-completion providers, else we might crash
         for (auto view : qAsConst(m_completionViews)) {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+            view->unregisterCompletionModel(m_completion.get());
+#else
             qobject_cast<KTextEditor::CodeCompletionInterface *>(view)->unregisterCompletionModel(m_completion.get());
-        }
-
-        // unregister all text-hint providers, else we might crash
-        for (auto view : qAsConst(m_hoverViews)) {
-            qobject_cast<KTextEditor::TextHintInterface *>(view)->unregisterTextHintProvider(m_forwardHover.get());
+#endif
         }
 
         clearAllLocationMarks();
@@ -952,6 +947,19 @@ public:
 
     static void clearMarks(KTextEditor::Document *doc, RangeCollection &ranges, DocumentCollection &docs, uint markType)
     {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        if (docs.contains(doc)) {
+            const QHash<int, KTextEditor::Mark *> marks = doc->marks();
+            QHashIterator<int, KTextEditor::Mark *> i(marks);
+            while (i.hasNext()) {
+                i.next();
+                if (i.value()->type & markType) {
+                    doc->removeMark(i.value()->line, markType);
+                }
+            }
+            docs.remove(doc);
+        }
+#else
         KTextEditor::MarkInterface *iface = docs.contains(doc) ? qobject_cast<KTextEditor::MarkInterface *>(doc) : nullptr;
         if (iface) {
             const QHash<int, KTextEditor::Mark *> marks = iface->marks();
@@ -964,6 +972,7 @@ public:
             }
             docs.remove(doc);
         }
+#endif
 
         for (auto it = ranges.find(doc); it != ranges.end() && it.key() == doc;) {
             delete it.value();
@@ -1017,7 +1026,6 @@ public:
         KTextEditor::Attribute::Ptr attr;
 
         bool enabled = false;
-        KTextEditor::MarkInterface::MarkTypes markType = RangeData::markType;
         switch (kind) {
         case RangeData::KindEnum::Text: {
             // well, it's a bit like searching for something, so re-use that color
@@ -1066,17 +1074,27 @@ public:
 
         // highlight the range
         if (enabled && ranges && attr) {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+            KTextEditor::MovingRange *mr = doc->newMovingRange(range);
+#else
             KTextEditor::MovingInterface *miface = qobject_cast<KTextEditor::MovingInterface *>(doc);
             Q_ASSERT(miface);
             KTextEditor::MovingRange *mr = miface->newMovingRange(range);
+#endif
             mr->setZDepth(-90000.0); // Set the z-depth to slightly worse than the selection
             mr->setAttribute(attr);
             mr->setAttributeOnlyForViews(true);
             ranges->insert(doc, mr);
         }
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        auto *iface = doc;
+        KTextEditor::Document::MarkTypes markType = RangeData::markType;
+#else
         KTextEditor::MarkInterfaceV2 *iface = qobject_cast<KTextEditor::MarkInterfaceV2 *>(doc);
         Q_ASSERT(iface);
+        KTextEditor::MarkInterface::MarkTypes markType = RangeData::markType;
+#endif
         // add match mark for range
         switch (markType) {
         case RangeData::markType:
@@ -1093,6 +1111,10 @@ public:
             docs->insert(doc);
         }
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        connect(doc, &KTextEditor::Document::aboutToInvalidateMovingInterfaceContent, this, &self_type::clearAllMarks, Qt::UniqueConnection);
+        connect(doc, &KTextEditor::Document::aboutToDeleteMovingInterfaceContent, this, &self_type::clearAllMarks, Qt::UniqueConnection);
+#else
         // ensure runtime match
         // clang-format off
         connect(doc,
@@ -1105,9 +1127,11 @@ public:
                 this,
                 SLOT(clearAllMarks(KTextEditor::Document*)),
                 Qt::UniqueConnection);
+        // clang-format on
+#endif
+
         // reload might save/restore marks before/after above signals, so let's clear before that
         connect(doc, &KTextEditor::Document::aboutToReload, this, &self_type::clearAllMarks, Qt::UniqueConnection);
-        // clang-format on
     }
 
     void addMarksRec(KTextEditor::Document *doc, QStandardItem *item, RangeCollection *ranges, DocumentCollection *docs)
@@ -1153,9 +1177,9 @@ public:
         }
         if (targetView) {
             // save current position for location history
-            Q_EMIT addPositionToHistory(activeView->document()->url(), activeView->cursorPosition());
+            Utils::addPositionToHistory(activeView->document()->url(), activeView->cursorPosition(), m_mainWindow);
             // save the position to which we are jumping in location history
-            Q_EMIT addPositionToHistory(targetView->document()->url(), cdef);
+            Utils::addPositionToHistory(targetView->document()->url(), cdef, m_mainWindow);
             targetView->setCursorPosition(cdef);
             highlightLandingLocation(targetView, location);
         }
@@ -1173,11 +1197,15 @@ public:
         if (!doc) {
             return;
         }
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        auto mr = doc->newMovingRange(location);
+#else
         auto miface = qobject_cast<KTextEditor::MovingInterface *>(doc);
         if (!miface) {
             return;
         }
         auto mr = miface->newMovingRange(location);
+#endif
         KTextEditor::Attribute::Ptr attr(new KTextEditor::Attribute);
         attr->setUnderlineStyle(QTextCharFormat::SingleUnderline);
         mr->setView(view);
@@ -1245,7 +1273,7 @@ public:
 
         auto range = activeView->selectionRange();
         if (!range.isValid()) {
-            range = document->documentRange();
+            range = {activeView->cursorPosition(), activeView->cursorPosition()};
         }
         server->documentCodeAction(url, range, {}, {diagnostic}, this, h);
     }
@@ -1811,10 +1839,15 @@ public:
 
         int tabSize = 4;
         bool insertSpaces = true;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        tabSize = document->configValue(QStringLiteral("tab-width")).toInt();
+        insertSpaces = document->configValue(QStringLiteral("replace-tabs")).toBool();
+#else
         auto cfgiface = qobject_cast<KTextEditor::ConfigInterface *>(document);
         Q_ASSERT(cfgiface);
         tabSize = cfgiface->configValue(QStringLiteral("tab-width")).toInt();
         insertSpaces = cfgiface->configValue(QStringLiteral("replace-tabs")).toBool();
+#endif
 
         // sigh, no move initialization capture ...
         // (again) assuming reply ranges wrt revisions submitted at this time
@@ -2026,7 +2059,7 @@ public:
         QPointer<KTextEditor::View> v(activeView);
         auto h = [this, v, position](const LSPExpandedMacro &reply) {
             if (v && !reply.expansion.isEmpty()) {
-                LspTooltip::show(reply.expansion, LSPMarkupKind::PlainText, v->mapToGlobal(v->cursorToCoordinate(position)), v, true);
+                m_textHintprovider.showTextHint(reply.expansion, TextHintMarkupKind::PlainText, position);
             } else {
                 showMessage(i18n("No results"), KTextEditor::Message::Information);
             }
@@ -2113,16 +2146,14 @@ public:
         updateState();
     }
 
-    QString onTextHint(KTextEditor::View *view, const KTextEditor::Cursor &position)
+    void onTextHint(KTextEditor::View *view, const KTextEditor::Cursor &position)
     {
-        bool autoHover = m_autoHover && m_autoHover->isChecked();
         // only trigger generic hover if no diagnostic to show;
         // avoids interference by generic hover info
         // (which is likely not so useful in this case/position anyway)
-        if (autoHover && !m_diagnosticProvider.hasTooltipForPos(view, position)) {
-            return m_hover->textHint(view, position);
+        if (m_autoHover && m_autoHover->isChecked()) {
+            m_hover->showTextHint(view, position, false);
         }
-        return {};
     }
 
     KTextEditor::View *viewForUrl(const QUrl &url) const
@@ -2404,9 +2435,6 @@ public:
 
         // update hover with relevant server
         m_hover->setServer(server && server->capabilities().hoverProvider ? server : nullptr);
-        // need hover either for generic documentHover or for diagnostics
-        // so register anyway if server available and will sort out what to do/show later
-        updateHover(activeView, server.get());
 
         updateMarks(doc);
 
@@ -2477,7 +2505,6 @@ public:
     void viewDestroyed(QObject *view)
     {
         m_completionViews.remove(static_cast<KTextEditor::View *>(view));
-        m_hoverViews.remove(static_cast<KTextEditor::View *>(view));
     }
 
     void updateCompletion(KTextEditor::View *view, LSPClientServer *server)
@@ -2488,46 +2515,32 @@ public:
 
         bool registered = m_completionViews.contains(view);
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         KTextEditor::CodeCompletionInterface *cci = qobject_cast<KTextEditor::CodeCompletionInterface *>(view);
         Q_ASSERT(cci);
+#endif
 
         if (!registered && server && server->capabilities().completionProvider.provider) {
             qCInfo(LSPCLIENT) << "registering cci";
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+            view->registerCompletionModel(m_completion.get());
+#else
             cci->registerCompletionModel(m_completion.get());
+#endif
             m_completionViews.insert(view);
         }
 
         if (registered && !server) {
             qCInfo(LSPCLIENT) << "unregistering cci";
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+            view->unregisterCompletionModel(m_completion.get());
+#else
             cci->unregisterCompletionModel(m_completion.get());
+#endif
             m_completionViews.remove(view);
         }
     }
 
-    void updateHover(KTextEditor::View *view, LSPClientServer *server)
-    {
-        if (!view) {
-            return;
-        }
-
-        bool registered = m_hoverViews.contains(view);
-
-        KTextEditor::TextHintInterface *cci = qobject_cast<KTextEditor::TextHintInterface *>(view);
-        Q_ASSERT(cci);
-
-        if (!registered && server) {
-            qCInfo(LSPCLIENT) << "registering thi";
-            cci->registerTextHintProvider(m_forwardHover.get());
-            m_hoverViews.insert(view);
-        }
-
-        if (registered && !server) {
-            qCInfo(LSPCLIENT) << "unregistering thi";
-            cci->unregisterTextHintProvider(m_forwardHover.get());
-            m_hoverViews.remove(view);
-        }
-    }
-
     Q_INVOKABLE QAbstractItemModel *documentSymbolsModel()
     {
         return m_symbolView->documentSymbolsModel();
