@@ -1,3 +1,7 @@
+/*
+    SPDX-FileCopyrightText: 2021 Waqar Ahmed <waqar.17a@gmail.com>
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 #include "branchdeletedialog.h"
 
 #include "git/gitutils.h"
@@ -20,7 +24,7 @@ class CheckableHeaderView : public QHeaderView
 {
     Q_OBJECT
 public:
-    CheckableHeaderView(Qt::Orientation orientation, QWidget *parent = nullptr)
+    explicit CheckableHeaderView(Qt::Orientation orientation, QWidget *parent = nullptr)
         : QHeaderView(orientation, parent)
     {
     }
@@ -212,3 +216,4 @@ void BranchDeleteDialog::onCheckAllClicked(bool checked)
 }
 
 #include "branchdeletedialog.moc"
+#include "moc_branchdeletedialog.cpp"
