@@ -29,7 +29,7 @@
 #include <KToolBar>
 #include <KXMLGUIFactory>
 
-#ifdef KF5Activities_FOUND
+#if defined(KF5Activities_FOUND) || defined(KF6Activities_FOUND)
 #include <KActivities/ResourceInstance>
 #endif
 
@@ -256,17 +256,7 @@ void KateViewManager::setupActions()
     a->setText(i18n("Welcome Page"));
     a->setIcon(qApp->windowIcon());
     connect(a, &QAction::triggered, this, [this]() {
-        if (activeViewSpace()) {
-            const auto widgets = activeViewSpace()->widgets();
-            for (const auto &widget : widgets) {
-                // check if there is already a welcome view
-                if (qobject_cast<WelcomeView *>(widget)) {
-                    return;
-                }
-            }
-
-            showWelcomeView();
-        }
+        showWelcomeView();
     });
     a->setWhatsThis(i18n("Show the welcome page"));
 }
@@ -371,11 +361,20 @@ void KateViewManager::slotDocumentOpen()
 
 void KateViewManager::slotDocumentClose(KTextEditor::Document *document)
 {
-    bool shutdownKate = m_mainWindow->modCloseAfterLast() && KateApp::self()->documentManager()->documentList().size() == 1;
+    // Close document
+    if (KateApp::self()->documentManager()->closeDocument(document) && KateApp::self()->documentManager()->documentList().size() == 0) {
+        // Close window if specified
+        if (m_mainWindow->modCloseAfterLast()) {
+            KateApp::self()->shutdownKate(m_mainWindow);
+        }
 
-    // close document
-    if (KateApp::self()->documentManager()->closeDocument(document) && shutdownKate) {
-        KateApp::self()->shutdownKate(m_mainWindow);
+        KSharedConfig::Ptr config = KSharedConfig::openConfig();
+        KConfigGroup cgGeneral = KConfigGroup(config, "General");
+
+        // Otherwise, show the welcome view
+        if (cgGeneral.readEntry("Show welcome view for new window", true)) {
+            showWelcomeView();
+        }
     }
 }
 
@@ -660,7 +659,7 @@ KTextEditor::View *KateViewManager::createView(KTextEditor::Document *doc, KateV
      */
     m_views[view].lruAge = m_minAge--;
 
-#ifdef KF5Activities_FOUND
+#if defined(KF5Activities_FOUND) || defined(KF6Activities_FOUND)
     m_views[view].activityResource = new KActivities::ResourceInstance(view->window()->winId(), view);
     m_views[view].activityResource->setUri(doc->url());
 #endif
@@ -870,7 +869,7 @@ void KateViewManager::activateView(KTextEditor::View *view)
 
         updateViewSpaceActions();
 
-#ifdef KF5Activities_FOUND
+#if defined(KF5Activities_FOUND) || defined(KF6Activities_FOUND)
         // inform activity manager
         m_views[view].activityResource->setUri(view->document()->url());
         m_views[view].activityResource->notifyFocusedIn();
@@ -1617,7 +1616,11 @@ void KateViewManager::moveSplitter(Qt::Key key, int repeats)
     int move = 4 * repeats;
     // try to use font height in pixel to move splitter
     {
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
         KTextEditor::Attribute::Ptr attrib(vs->currentView()->defaultStyleAttribute(KTextEditor::dsNormal));
+#else
+        KTextEditor::Attribute::Ptr attrib(vs->currentView()->defaultStyleAttribute(KSyntaxHighlighting::Theme::TextStyle::Normal));
+#endif
         QFontMetrics fm(attrib->font());
         move = fm.height() * repeats;
     }
@@ -1707,6 +1710,17 @@ void KateViewManager::showWelcomeViewOrNewDocumentIfNeeded()
 
 void KateViewManager::showWelcomeView()
 {
+    // Find and activate existing welcome view
+    if (activeViewSpace()) {
+        const auto widgets = activeViewSpace()->widgets();
+        for (const auto &widget : widgets) {
+            if (qobject_cast<WelcomeView *>(widget)) {
+                activateWidget(widget);
+                return;
+            }
+        }
+    }
+
     auto welcomeView = new WelcomeView(this);
     mainWindow()->addWidget(welcomeView);
     m_welcomeViewAlreadyShown = true;
@@ -1732,3 +1746,5 @@ void KateViewManager::triggerActiveViewFocus()
         }
     });
 }
+
+#include "moc_kateviewmanager.cpp"
