@@ -4,8 +4,7 @@
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef SAVEDSESSIONSMODEL_H
-#define SAVEDSESSIONSMODEL_H
+#pragma once
 
 #include "katesessionmanager.h"
 
@@ -29,12 +28,11 @@ private:
         QDateTime lastOpened;
         QString name;
 
-        bool operator<(const SessionInfo &other) const {
+        bool operator<(const SessionInfo &other) const
+        {
             return lastOpened > other.lastOpened;
         }
     };
 
     QVector<SessionInfo> m_sessions;
 };
-
-#endif // SAVEDSESSIONSMODEL_H
